@@ -7,7 +7,7 @@ contained in these mix-ins keeps the main factory class cleaner
 import concurrent.futures
 import logging
 import shutil
-import subprocess
+from subprocess import Popen, PIPE, CalledProcessError
 import sys
 import uuid
 from time import sleep
@@ -166,7 +166,7 @@ class FactoryPackMixin:
                     result.result()
                 except (
                     git.GitCommandError,
-                    subprocess.CalledProcessError,
+                    CalledProcessError,
                     NotADirectoryError,
                     PermissionError,
                     FileNotFoundError,
@@ -522,7 +522,7 @@ class FactoryBuildMixin:
 
         qalx = shutil.which("qalx")
 
-        output = subprocess.Popen(
+        output = Popen(
             [
                 qalx,
                 "--user-profile",
@@ -535,7 +535,7 @@ class FactoryBuildMixin:
             ],
             # Redirect pipe to stderr so we can capture
             # errors to give to the user in the main thread
-            stderr=subprocess.PIPE,
+            stderr=PIPE,
             env=modified_env,
         )
 
