@@ -1,5 +1,6 @@
 import logging
 import os
+from io import StringIO
 
 import boto3
 import requests
@@ -147,6 +148,7 @@ class AWSProvider(BaseProvider):
                     "cloudformation:DescribeStacks",
                     "cloudformation:DescribeStackEvents",
                     "cloudformation:UpdateTerminationProtection",
+                    "cloudwatch:PutMetricData",
                     "ec2:CreateTags",
                     "ec2:DescribeImages",
                     "ec2:DescribeInstances",
@@ -186,6 +188,15 @@ class AWSProvider(BaseProvider):
                     "arn:aws:ec2:*:*:instance/*",
                 ],
             ),
+            (
+                [
+                    "cloudwatch:EnableAlarmActions",
+                    "cloudwatch:DeleteAlarms",
+                    "cloudwatch:DisableAlarmActions",
+                    "cloudwatch:PutMetricAlarm",
+                ],
+                ["arn:aws:cloudwatch:*:*:alarm:*"],
+            ),
         ]
 
         results = []
@@ -231,12 +242,25 @@ class AWSProvider(BaseProvider):
             raise QalxFactoryError(msg)
 
     def _create_stack(self, stack):
+        """
+        Creates the Cloudformation Stack for the given template.  Uploads
+        the stack as a file Item to allow us to take advantage of the larger
+        file size allowed when using TemplateURL.  This item will be
+        automatically deleted when the factory is deleted.
+        :param stack:
+        :return:
+        """
         stack_name = self._stack_name()
         client = self._get_client()
+        item = self.factory.session.item.add(
+            source=StringIO(stack),
+            file_name=self.factory._plan_name,
+            meta=self.factory._metadata(self.factory.entity),
+        )
         try:
             resp = client.create_stack(
                 StackName=stack_name,
-                TemplateBody=stack,
+                TemplateURL=item["file"]["url"],
                 OnFailure="DELETE",
                 EnableTerminationProtection=True,
                 Capabilities=["CAPABILITY_NAMED_IAM"],
