@@ -4,11 +4,14 @@ import sys
 import click
 from click import ClickException
 
+from pyqalx import QalxSession
 from pyqalx.config import UserConfig, BotConfig
 from pyqalx.core.errors import (
     QalxConfigProfileNotFound,
     QalxConfigFileNotFound,
     QalxConfigError,
+    QalxAPIResponseError,
+    QalxError,
 )
 from qalxcli import cli_types
 from qalxcli.utils import generate_key_file
@@ -141,3 +144,43 @@ def generate_encryption():
         + "file to be used, by adding the following line under the appropriate "
         + f"profile:\n\nKEYFILE={key_file_path}"
     )
+
+
+@qalx.command("download")
+@click.argument("guid")
+@click.option(
+    "-d",
+    "--directory",
+    type=cli_types.DIR_PATH_EXISTING,
+    help="The directory where the file will be downloaded.",
+    default=None,
+)
+@click.option(
+    "-e",
+    "--entity-type",
+    type=cli_types.FILE_ENTITY_TYPE,
+    help="The type of entity to download a file for.",
+    default="item",
+)
+@click.pass_context
+def download(ctx, guid, directory, entity_type):
+    """
+    Downloads a file for the specified entity type and guid. The download
+    directory can also be specified, otherwise the default location from the
+    qalx config file will be used
+    """
+    qalx_session = QalxSession(profile_name=ctx.obj["USER_PROFILE"])
+    if directory is None:
+        directory = qalx_session.config["DOWNLOAD_DIR"]
+        # The directory from the config might not exist
+        if not os.path.exists:
+            os.mkdir(directory)
+    try:
+        entity = getattr(qalx_session, entity_type).get(guid)
+    except QalxAPIResponseError as exc:
+        msg = f"{entity_type} with guid: {guid} not found:\n\n{exc}"
+        raise ClickException(msg)
+    try:
+        entity.save_file_to_disk(directory)
+    except QalxError as exc:
+        raise ClickException(exc)
