@@ -382,7 +382,14 @@ class FactoryTabulation(QalxCLITabulation):
 
     @staticmethod
     def build_headers():
-        return ["Index", "Name", "Status", "Created On (UTC)", "Created By"]
+        return [
+            "Index",
+            "Name",
+            "Stage",
+            "Status",
+            "Created On (UTC)",
+            "Created By",
+        ]
 
     @staticmethod
     def build_row(index, entity):
@@ -392,6 +399,7 @@ class FactoryTabulation(QalxCLITabulation):
         row = [
             index,
             entity["name"],
+            entity["stage"],
             entity["status"],
             created_on,
             entity["info"]["created"]["by"]["email"],
